# Basic Properties

This page lists [solution_name]'s basic properties; for advanced and deprecated properties, refer to [all properties](all-properties.md).


## [packagist](detectors/packagist.md)

| Property | Description |
| --- | --- |
| [detect.packagist.include.dev.dependencies](detectors/packagist.md#include-packagist-development-dependencies) | default: true <br /><br /> Include Packagist Development Dependencies: Set this value to false if you would like to exclude your dev requires dependencies when ran. <br /><br />  |


## [impact-analysis](configuration/impact-analysis.md)

| Property | Description |
| --- | --- |
| [detect.impact.analysis.enabled](configuration/impact-analysis.md#vulnerability-impact-analysis-enabled) | default: false <br /><br /> Vulnerability Impact Analysis Enabled: If set to true, Detect will attempt to look for *.class files and generate a Vulnerability Impact Analysis Report for upload to Black Duck. <br /><br />  |
| [detect.impact.analysis.output.path](configuration/impact-analysis.md#impact-analysis-output-directory) | Impact Analysis Output Directory: The path to the output directory for Impact Analysis reports. <br /><br />  |


## [sbt](detectors/sbt.md)

| Property | Description |
| --- | --- |
| [detect.sbt.arguments](detectors/sbt.md#additional-sbt-command-arguments) | Additional sbt command Arguments: A space-separated list of additional arguments to add to sbt command line when running Detect against an SBT project. Detect will execute the command 'sbt {additional arguments} {Detect-added arguments}'. <br /><br />  |


## [bitbake](detectors/bitbake.md)

| Property | Description |
| --- | --- |
| [detect.bitbake.build.env.name](detectors/bitbake.md#bitbake-init-script-name) | default: oe-init-build-env <br /><br /> BitBake Init Script Name: The name of the build environment init script. <br /><br />  |
| [detect.bitbake.package.names](detectors/bitbake.md#bitbake-package-names) | BitBake Package Names: A comma-separated list of package names from which dependencies are extracted. <br /><br />  |
| [detect.bitbake.source.arguments](detectors/bitbake.md#bitbake-source-arguments) | BitBake Source Arguments: A comma-separated list of arguments to supply when sourcing the build environment init script. <br /><br />  |
| [detect.bitbake.search.depth](detectors/bitbake.md#bitbake-search-depth) | default: 1 <br /><br /> BitBake Search Depth: The depth at which Detect will search for files generated by Bitbake. <br /><br />  |


## [conan](detectors/conan.md)

| Property | Description |
| --- | --- |
| [detect.conan.path](detectors/conan.md#conan-executable) | Conan Executable: The path to the conan executable. <br /><br />  |
| [detect.conan.include.build.dependencies](detectors/conan.md#include-conan-build-dependencies) | default: true <br /><br /> Include Conan Build Dependencies: Set this value to false if you would like to exclude your project's build dependencies. <br /><br />  |
| [detect.conan.arguments](detectors/conan.md#additional-conan-arguments) | Additional Conan Arguments: A space-separated list of additional arguments to add to the 'conan info' command line when running Detect against a Conan project. Detect will execute the command 'conan info {additional arguments} .' <br /><br />  |
| [detect.conan.lockfile.path](detectors/conan.md#conan-lockfile) | Conan Lockfile: The path to the conan lockfile to apply when running 'conan info' to get the dependency graph. If set, Detect will execute the command 'conan info --lockfile {lockfile} .' <br /><br />  |
| [detect.conan.attempt.package.revision.match](detectors/conan.md#attempt-package-revision-match) | default: false <br /><br /> Attempt Package Revision Match: If package revisions are available (a Conan lock file is found or provided, and Conan's revisions feature is enabled), require that each dependency's package revision match the package revision of the component in the KB. <br /><br />  |


## [project](configuration/project.md)

| Property | Description |
| --- | --- |
| [detect.policy.check.fail.on.severities](configuration/project.md#fail-on-policy-violation-severities) | default: NONE <br /><br />  Acceptable Values: ALL, NONE, BLOCKER, CRITICAL, MAJOR, MINOR, OK, TRIVIAL, UNSPECIFIED <br /><br />Fail on Policy Violation Severities: A comma-separated list of policy violation severities that will fail Detect. If this is set to NONE, Detect will not fail due to policy violations. A value of ALL is equivalent to all of the other possible values except NONE. <br /><br />  |
| [detect.project.description](configuration/project.md#project-description) | Project Description: If project description is specified, your project version will be created with this description. <br /><br />  |
| [detect.project.name](configuration/project.md#project-name) | Project Name: An override for the name to use for the Black Duck project. If not supplied, Detect will attempt to use the tools to figure out a reasonable project name. If that fails, the final part of the directory path where the inspection is taking place will be used. <br /><br />  |
| [detect.project.tier](configuration/project.md#project-tier) | Project Tier: If a Black Duck project tier is specified, your project will be created with this tier. <br /><br />  |
| [detect.project.version.name](configuration/project.md#version-name) | Version Name: An override for the version to use for the Black Duck project. If not supplied, Detect will attempt to use the tools to figure out a reasonable version name. If that fails, the current date will be used. <br /><br />  |
| [detect.project.version.nickname](configuration/project.md#version-nickname) | Version Nickname: If a project version nickname is specified, your project version will be created with this nickname. <br /><br />  |
| [detect.project.version.notes](configuration/project.md#version-notes) | Version Notes: If project version notes are specified, your project version will be created with these notes. <br /><br />  |
| [detect.project.version.phase](configuration/project.md#version-phase) | default: DEVELOPMENT <br /><br />  Acceptable Values: ARCHIVED, DEPRECATED, DEVELOPMENT, PLANNING, PRERELEASE, RELEASED <br /><br />Version Phase: An override for the Project Version phase. <br /><br />  |
| [detect.project.version.update](configuration/project.md#update-project-version) | default: false <br /><br /> Update Project Version: If set to true, will update the Project Version with the configured properties. See detailed help for more information. <br /><br />  |


## [pnpm](detectors/pnpm.md)

| Property | Description |
| --- | --- |
| [detect.pnpm.dependency.types](detectors/pnpm.md#pnpm-dependency-types) | default: ALL <br /><br />  Acceptable Values: ALL, NONE, APP, DEV, OPTIONAL <br /><br />pnpm Dependency Types: Set this value to indicate which types of pnpm dependencies you want Detect to report. <br /><br />  |


## [docker](detectors/docker.md)

| Property | Description |
| --- | --- |
| [detect.docker.image](detectors/docker.md#docker-image-name) | Docker Image Name: The Docker image name (repo:tag) to inspect. <br /><br />  |
| [detect.docker.image.id](detectors/docker.md#docker-image-id) | Docker Image ID: The ID (shown in the 'IMAGE ID' column of 'docker images' output) of the target Docker image. The target image must already be local (must appear in the output of 'docker images'). <br /><br />  |
| [detect.docker.path](detectors/docker.md#docker-executable) | Docker Executable: Path to the docker executable (used to load image inspector Docker images in order to run the Docker Inspector in air gap mode). <br /><br />  |
| [detect.docker.tar](detectors/docker.md#image-archive-file) | Image Archive File: An image .tar file which is either a Docker image saved to a file using the 'docker save' command, or an Open Container Initiative (OCI) image .tar file. The file must be readable by all. <br /><br />  |


## [bazel](detectors/bazel.md)

| Property | Description |
| --- | --- |
| [detect.bazel.path](detectors/bazel.md#bazel-executable) | Bazel Executable: The path to the Bazel executable. <br /><br />  |
| [detect.bazel.target](detectors/bazel.md#bazel-target) | Bazel Target: The Bazel target (for example, //foo:foolib) for which dependencies are collected. For Detect to run Bazel, this property must be set. <br /><br />  |
| [detect.bazel.cquery.options](detectors/bazel.md#bazel-cquery-additional-options) | Bazel cquery additional options: A comma-separated list of additional options to pass to the bazel cquery command. <br /><br />  |
| [detect.bazel.dependency.type](detectors/bazel.md#bazel-workspace-external-dependency-rule) |  Acceptable Values: ALL, NONE, MAVEN_JAR, MAVEN_INSTALL, HASKELL_CABAL_LIBRARY <br /><br />Bazel workspace external dependency rule: The Bazel workspace rule(s) used to pull in external dependencies. If not set, Detect will attempt to determine the rule(s) from the contents of the WORKSPACE file. <br /><br />  |


## [dart](detectors/dart.md)

| Property | Description |
| --- | --- |
| [detect.dart.path](detectors/dart.md#dart-executable) | dart Executable: The path to the dart executable. <br /><br />  |
| [detect.flutter.path](detectors/dart.md#flutter-executable) | flutter Executable: The path to the flutter executable. <br /><br />  |


## [general](configuration/general.md)

| Property | Description |
| --- | --- |
| [detect.detector.buildless](configuration/general.md#buildless-mode) | default: false <br /><br /> Buildless Mode: If set to true, only Detector's capable of running without a build will be run. <br /><br />  |
| [detect.target.type](configuration/general.md#detect-target) | default: SOURCE <br /><br />  Acceptable Values: SOURCE, IMAGE <br /><br />Detect Target: Informs detect of what is being scanned which allows improved user experience when scanning different types of targets. <br /><br />  |
| [detect.wait.for.results](configuration/general.md#wait-for-results) | default: false <br /><br /> Wait For Results: If set to true, Detect will wait for Synopsys products until results are available or the detect.report.timeout is exceeded. <br /><br />  |
| [detect.follow.symbolic.links](configuration/general.md#follow-symbolic-links) | default: true <br /><br /> Follow Symbolic Links: If set to true, Detect will follow symbolic links when searching for detectors, when searching for files that select detectors (such as Bitbake and Sbt) need, when searching for directories to exclude from signature scan, and when searching for binary scan targets.  Symbolic links are not supported for Impact Analysis. <br /><br />  |


## [pear](detectors/pear.md)

| Property | Description |
| --- | --- |
| [detect.pear.only.required.deps](detectors/pear.md#include-only-required-pear-dependencies) | default: false <br /><br /> Include Only Required Pear Dependencies: Set to true if you would like to include only required packages. <br /><br />  |
| [detect.pear.path](detectors/pear.md#pear-executable) | Pear Executable: The path to the pear executable. <br /><br />  |


## [pip](detectors/pip.md)

| Property | Description |
| --- | --- |
| [detect.pip.project.name](detectors/pip.md#pip-project-name) | PIP Project Name: The name of your PIP project, to be used if your project's name cannot be correctly inferred from its setup.py file. <br /><br />  |
| [detect.pip.project.version.name](detectors/pip.md#pip-project-version-name) | PIP Project Version Name: The version of your PIP project, to be used if your project's version name cannot be correctly inferred from its setup.py file. <br /><br />  |
| [detect.pip.requirements.path](detectors/pip.md#pip-requirements-path) | PIP Requirements Path: A comma-separated list of paths to requirements files, to be used to analyze requirements files with a filename other than requirements.txt or to specify which requirements files should be analyzed. <br /><br />  |
| [detect.pip.only.project.tree](detectors/pip.md#pip-include-only-project-tree) | default: false <br /><br /> PIP Include Only Project Tree: By default, pipenv includes all dependencies found in the graph. Set to true to only include dependencies found underneath the dependency that matches the provided pip project and version name. <br /><br />  |
| [detect.pip.path](detectors/pip.md#pip-executable) | Pip Executable: The path to the Pip executable. <br /><br />  |
| [detect.pipenv.path](detectors/pip.md#pipenv-executable) | Pipenv Executable: The path to the Pipenv executable. <br /><br />  |


## [conda](detectors/conda.md)

| Property | Description |
| --- | --- |
| [detect.conda.environment.name](detectors/conda.md#anaconda-environment-name) | Anaconda Environment Name: The name of the anaconda environment used by your project. <br /><br />  |
| [detect.conda.path](detectors/conda.md#conda-executable) | Conda Executable: The path to the conda executable. <br /><br />  |


## [binary-scanner](configuration/binary-scanner.md)

| Property | Description |
| --- | --- |
| [detect.binary.scan.file.path](configuration/binary-scanner.md#binary-scan-target) | Binary Scan Target: If specified, this file and this file only will be uploaded for binary scan analysis. This property takes precedence over detect.binary.scan.file.name.patterns. The BINARY_SCAN tool does not provide project and version name defaults to Detect, so you need to set project and version names via properties when only the BINARY_SCAN tool is invoked. <br /><br />  |
| [detect.binary.scan.file.name.patterns](configuration/binary-scanner.md#binary-scan-filename-patterns) | Binary Scan Filename Patterns: If specified, all files in the source directory whose names match these file name patterns will be zipped and uploaded for binary scan analysis. This property will not be used if detect.binary.scan.file.path is specified. Search depth is controlled by property detect.binary.scan.search.depth. This property accepts filename globbing-style wildcards. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details. <br /><br />  |
| [detect.binary.scan.search.depth](configuration/binary-scanner.md#binary-scan-search-depth) | default: 0 <br /><br /> Binary Scan Search Depth: When binary scan filename patterns are being used to search for binary files to scan, this property sets the depth at which Detect will search for files (that match those patterns) to upload for binary scan analysis. <br /><br />  |


## [hex](detectors/hex.md)

| Property | Description |
| --- | --- |
| [detect.hex.rebar3.path](detectors/hex.md#rebar3-executable) | Rebar3 Executable: The path to the rebar3 executable. <br /><br />  |


## [python](detectors/python.md)

| Property | Description |
| --- | --- |
| [detect.python.path](detectors/python.md#python-executable) | Python Executable: The path to the Python executable. <br /><br />  |


## [debug](configuration/debug.md)

| Property | Description |
| --- | --- |
| [detect.diagnostic](configuration/debug.md#diagnostic-mode) | default: false <br /><br /> Diagnostic Mode: When enabled, diagnostic mode collects all files generated by Synopsys Detect and zips the files using a unique run ID. It includes logs, BDIO files, extraction files, and reports. <br /><br />  |
| [detect.diagnostic.extended](configuration/debug.md#diagnostic-mode-extended) | default: false <br /><br /> Diagnostic Mode Extended: When enabled, Synopsys Detect performs the actions of --detect.diagnostic, but also includes relevant files such as lock files and build artifacts. <br /><br />  |


## [maven](detectors/maven.md)

| Property | Description |
| --- | --- |
| [detect.maven.build.command](detectors/maven.md#maven-build-command) | Maven Build Command: Maven command line arguments to add to the mvn/mvnw command line. <br /><br />  |
| [detect.maven.path](detectors/maven.md#maven-executable) | Maven Executable: The path to the Maven executable (mvn or mvnw). <br /><br />  |
| [detect.maven.included.scopes](detectors/maven.md#dependency-scope-included) | Dependency Scope Included: A comma separated list of Maven scopes. Output will be limited to dependencies within these scopes (overridden by exclude). <br /><br />  |
| [detect.maven.excluded.scopes](detectors/maven.md#dependency-scope-excluded) | Dependency Scope Excluded: A comma separated list of Maven scopes. Output will be limited to dependencies outside these scopes (overrides include). <br /><br />  |


## [go](detectors/go.md)

| Property | Description |
| --- | --- |
| [detect.go.path](detectors/go.md#go-executable) | Go Executable: Path to the Go executable. <br /><br />  |
| [detect.go.mod.enable.verification](detectors/go.md#go-mod-dependency-verification) | default: true <br /><br /> Go Mod Dependency Verification: When enabled, Detect will use the results of 'go mod why' to filter out unused dependencies. Set to false if you have an empty BOM. <br /><br />  |


## [npm](detectors/npm.md)

| Property | Description |
| --- | --- |
| [detect.npm.arguments](detectors/npm.md#additional-npm-command-arguments) | Additional NPM Command Arguments: A space-separated list of additional arguments that Detect will add at then end of the npm ls command line when Detect executes the NPM CLI Detector on an NPM project. <br /><br />  |
| [detect.npm.include.dev.dependencies](detectors/npm.md#include-npm-development-dependencies) | default: true <br /><br /> Include NPM Development Dependencies: Set this value to false if you would like to exclude your dev dependencies when ran. <br /><br />  |
| [detect.npm.include.peer.dependencies](detectors/npm.md#include-npm-peer-dependencies) | default: true <br /><br /> Include NPM Peer Dependencies: Set this value to false if you would like to exclude your peer dependencies when ran. <br /><br />  |
| [detect.npm.path](detectors/npm.md#npm-executable) | NPM Executable: The path to the Npm executable. <br /><br />  |


## [blackduck-server](configuration/blackduck-server.md)

| Property | Description |
| --- | --- |
| [blackduck.api.token](configuration/blackduck-server.md#black-duck-api-token) | Black Duck API Token: The access token used to authenticate with the Black Duck Server. <br /><br />  |
| [blackduck.offline.mode](configuration/blackduck-server.md#offline-mode) | default: false <br /><br /> Offline Mode: This can disable any Black Duck communication - if true, Detect will not upload BDIO files, it will not check policies, and it will not download and install the signature scanner. <br /><br />  |
| [blackduck.url](configuration/blackduck-server.md#black-duck-url) | Black Duck URL: URL of the Black Duck server. <br /><br />  |
| [detect.test.connection](configuration/blackduck-server.md#test-connection-to-black-duck) | default: false <br /><br /> Test Connection to Black Duck: Test the connection to Black Duck with the current configuration. <br /><br />  |


## [nuget](detectors/nuget.md)

| Property | Description |
| --- | --- |
| [detect.dotnet.path](detectors/nuget.md#dotnet-executable) | dotnet Executable: The path to the dotnet executable. <br /><br />  |
| [detect.nuget.config.path](detectors/nuget.md#nuget-config-file) | Nuget Config File: The path to the Nuget.Config file to supply to the nuget exe. <br /><br />  |
| [detect.nuget.packages.repo.url](detectors/nuget.md#nuget-packages-repository-url) | default: https://api.nuget.org/v3/index.json <br /><br /> Nuget Packages Repository URL: The source for nuget packages <br /><br />  |


## [lerna](detectors/lerna.md)

| Property | Description |
| --- | --- |
| [detect.lerna.path](detectors/lerna.md#lerna-executable) | Lerna Executable: Path of the lerna executable. <br /><br />  |
| [detect.lerna.include.private](detectors/lerna.md#include-lerna-packages-defined-as-private46) | default: false <br /><br /> Include Lerna Packages defined as private.: Lerna allows for private packages that do not get published. Set this to true to include all packages including private packages. <br /><br />  |


## [ruby](detectors/ruby.md)

| Property | Description |
| --- | --- |
| [detect.ruby.include.runtime.dependencies](detectors/ruby.md#ruby-runtime-dependencies) | default: true <br /><br /> Ruby Runtime Dependencies: If set to false, runtime dependencies will not be included when parsing *.gemspec files. <br /><br />  |
| [detect.ruby.include.dev.dependencies](detectors/ruby.md#ruby-development-dependencies) | default: false <br /><br /> Ruby Development Dependencies: If set to true, development dependencies will be included when parsing *.gemspec files. <br /><br />  |


## [gradle](detectors/gradle.md)

| Property | Description |
| --- | --- |
| [detect.gradle.build.command](detectors/gradle.md#gradle-build-command) | Gradle Build Command: Gradle command line arguments to add to the gradle/gradlew command line. <br /><br />  |
| [detect.gradle.path](detectors/gradle.md#gradle-executable) | Gradle Executable: The path to the Gradle executable (gradle or gradlew). <br /><br />  |


## [cpan](detectors/cpan.md)

| Property | Description |
| --- | --- |
| [detect.cpan.path](detectors/cpan.md#cpan-executable) | cpan Executable: The path to the cpan executable. <br /><br />  |
| [detect.cpanm.path](detectors/cpan.md#cpanm-executable) | cpanm Executable: The path to the cpanm executable. <br /><br />  |


## [cleanup](configuration/cleanup.md)

| Property | Description |
| --- | --- |
| [detect.cleanup](configuration/cleanup.md#cleanup-output) | default: true <br /><br /> Cleanup Output: If true, the files created by Detect will be cleaned up. <br /><br />  |


## [paths](configuration/paths.md)

| Property | Description |
| --- | --- |
| [detect.bash.path](configuration/paths.md#bash-executable) | Bash Executable: Path to the Bash executable. <br /><br />  |
| [detect.bdio.output.path](configuration/paths.md#bdio-output-directory) | BDIO Output Directory: The path to the output directory for all BDIO files. <br /><br />  |
| [detect.detector.search.depth](configuration/paths.md#detector-search-depth) | default: 0 <br /><br /> Detector Search Depth: Depth of subdirectories within the source directory to which Detect will search for files that indicate whether a detector applies. <br /><br />  |
| [detect.git.path](configuration/paths.md#git-executable) | Git Executable: Path of the git executable <br /><br />  |
| [detect.java.path](configuration/paths.md#java-executable) | Java Executable: Path to the java executable. <br /><br />  |
| [detect.output.path](configuration/paths.md#detect-output-path) | Detect Output Path: The path to the output directory. <br /><br />  |
| [detect.swift.path](configuration/paths.md#swift-executable) | Swift Executable: Path of the swift executable. <br /><br />  |
| [detect.sbt.path](configuration/paths.md#sbt-executable) | Sbt Executable: Path to the Sbt executable. <br /><br />  |
| [detect.scan.output.path](configuration/paths.md#scan-output-path) | Scan Output Path: The output directory for all signature scanner output files. If not set, the signature scanner output files will be in a 'scan' subdirectory of the output directory. <br /><br />  |
| [detect.source.path](configuration/paths.md#source-path) | Source Path: The source path is the path to the project directory to inspect. If no value is provided, the source path defaults to the current working directory. <br /><br />  |
| [detect.tools](configuration/paths.md#detect-tools-included) |  Acceptable Values: ALL, NONE, DETECTOR, SIGNATURE_SCAN, BINARY_SCAN, IMPACT_ANALYSIS, POLARIS, DOCKER, BAZEL <br /><br />Detect Tools Included: The tools Detect should allow in a comma-separated list. Tools in this list (as long as they are not also in the excluded list) will be allowed to run if all criteria of the tool are met. Exclusion rules always win. <br /><br />  |
| [detect.tools.excluded](configuration/paths.md#detect-tools-excluded) |  Acceptable Values: ALL, NONE, DETECTOR, SIGNATURE_SCAN, BINARY_SCAN, IMPACT_ANALYSIS, POLARIS, DOCKER, BAZEL <br /><br />Detect Tools Excluded: The tools Detect should not allow, in a comma-separated list. Excluded tools will not be run even if all criteria for the tool is met. Exclusion rules always win. <br /><br />  |


## [report](configuration/report.md)

| Property | Description |
| --- | --- |
| [detect.notices.report](configuration/report.md#generate-notices-report) | default: false <br /><br /> Generate Notices Report: When set to true, a Black Duck notices report in text form will be created in your source directory. <br /><br />  |
| [detect.notices.report.path](configuration/report.md#notices-report-path) | Notices Report Path: The output directory for notices report. Default is the source directory. <br /><br />  |
| [detect.risk.report.pdf](configuration/report.md#generate-risk-report-40pdf41) | default: false <br /><br /> Generate Risk Report (PDF): When set to true, a Black Duck risk report in PDF form will be created. <br /><br />  |
| [detect.risk.report.pdf.path](configuration/report.md#risk-report-output-path) | Risk Report Output Path: The output directory for risk report in PDF. Default is the source directory. <br /><br />  |


## [signature-scanner](configuration/signature-scanner.md)

| Property | Description |
| --- | --- |
| [detect.blackduck.signature.scanner.arguments](configuration/signature-scanner.md#signature-scanner-arguments) | Signature Scanner Arguments: Additional arguments to use when running the Black Duck signature scanner. <br /><br />  |
| [detect.blackduck.signature.scanner.copyright.search](configuration/signature-scanner.md#signature-scanner-copyright-search) | default: false <br /><br /> Signature Scanner Copyright Search: When set to true, user will be able to scan and discover copyright names in Black Duck. Corresponding Signature Scanner CLI Argument: --copyright-search. <br /><br />  |
| [detect.blackduck.signature.scanner.dry.run](configuration/signature-scanner.md#signature-scanner-dry-run) | default: false <br /><br /> Signature Scanner Dry Run: If set to true, the signature scanner results are not uploaded to Black Duck, and the scanner results are written to disk via the Signature Scanner CLI argument: --dryRunWriteDir. <br /><br />  |
| [detect.blackduck.signature.scanner.individual.file.matching](configuration/signature-scanner.md#individual-file-matching) | default: NONE <br /><br />  Acceptable Values: NONE, SOURCE, BINARY, ALL <br /><br />Individual File Matching: Users may set this property to indicate what types of files they want to match. Corresponding Signature Scanner CLI Argument: --individualFileMatching. <br /><br />  |
| [detect.blackduck.signature.scanner.license.search](configuration/signature-scanner.md#signature-scanner-license-search) | default: false <br /><br /> Signature Scanner License Search: When set to true, user will be able to scan and discover license names in Black Duck. Corresponding Signature Scanner CLI Argument: --license-search. <br /><br />  |
| [detect.blackduck.signature.scanner.local.path](configuration/signature-scanner.md#signature-scanner-local-path) | Signature Scanner Local Path: To use a local signature scanner, specify the path where the signature scanner was unzipped. This will likely look similar to 'scan.cli-x.y.z' and includes the 'bin, icon, jre, and lib' directories of the expanded scan.cli. <br /><br />  |
| [detect.blackduck.signature.scanner.paths](configuration/signature-scanner.md#signature-scanner-target-paths) | Signature Scanner Target Paths: If this property is not set, the signature scanner target path is the source path (see property detect.source.path). If this property is set, the paths provided in this property's value will be signature scanned instead (the signature scanner will be executed once for each provided path). <br /><br />  |
| [detect.blackduck.signature.scanner.snippet.matching](configuration/signature-scanner.md#snippet-matching) | default: NONE <br /><br />  Acceptable Values: NONE, SNIPPET_MATCHING, SNIPPET_MATCHING_ONLY, FULL_SNIPPET_MATCHING, FULL_SNIPPET_MATCHING_ONLY <br /><br />Snippet Matching: Use this value to enable the various snippet scanning modes. For a full explanation, please refer to the 'Running a component scan using the Signature Scanner command line' section in your Black Duck server's online help. Corresponding Signature Scanner CLI Arguments: --snippet-matching, --snippet-matching-only, --full-snippet-scan. <br /><br />  |
| [detect.blackduck.signature.scanner.upload.source.mode](configuration/signature-scanner.md#upload-source-mode) | default: false <br /><br /> Upload source mode: If set to true, the signature scanner will, if supported by your Black Duck version, upload source code to Black Duck. Corresponding Signature Scanner CLI Argument: --upload-source. <br /><br />  |
| [detect.excluded.directories.search.depth](configuration/signature-scanner.md#detect-excluded-directories-search-depth) | default: 4 <br /><br /> Detect Excluded Directories Search Depth: Enables you to adjust the depth to which Detect will search when creating signature scanner exclusion patterns. <br /><br />  |


## [logging](configuration/logging.md)

| Property | Description |
| --- | --- |
| [logging.level.com.synopsys.integration](configuration/logging.md#logging-level) | default: INFO <br /><br />  Acceptable Values: OFF, ERROR, WARN, INFO, DEBUG, TRACE <br /><br />Logging Level: The logging level of Detect. <br /><br />  |
| [logging.level.detect](configuration/logging.md#logging-level-shorthand) | default: INFO <br /><br />  Acceptable Values: OFF, ERROR, WARN, INFO, DEBUG, TRACE <br /><br />Logging Level Shorthand: Shorthand for the logging level of detect. Equivalent to setting logging.level.com.synopsys.integration. <br /><br />  |


## [yarn](detectors/yarn.md)

| Property | Description |
| --- | --- |
| [detect.yarn.prod.only](detectors/yarn.md#include-yarn-production-dependencies-only) | default: false <br /><br /> Include Yarn Production Dependencies Only: Set this to true to only scan production dependencies. <br /><br />  |


## [detector](configuration/detector.md)

| Property | Description |
| --- | --- |
| [detect.required.detector.types](configuration/detector.md#required-detect-types) |  Acceptable Values: BITBAKE, CARGO, CARTHAGE, COCOAPODS, CONAN, CONDA, CPAN, CRAN, DART, GIT, GO_MOD, GO_DEP, GO_VNDR, GO_VENDOR, GO_GRADLE, GRADLE, HEX, LERNA, MAVEN, NPM, NUGET, PACKAGIST, PEAR, PIP, PNPM, POETRY, RUBYGEMS, SBT, SWIFT, YARN, CLANG <br /><br />Required Detect Types: The set of required detectors. <br /><br />  |

