# maven

## Maven Build Command
```
--detect.maven.build.command
```

Maven command line arguments to add to the mvn/mvnw command line\.

By default, Detect runs the mvn \(or mvnw\) command with one argument: dependency:tree\. You can use this property to insert one or more additional mvn command line arguments \(goals, etc\.\) before the dependency:tree argument\. For example: suppose you are running in bash on Linux, and want to point maven to your settings file \(maven\_dev\_settings\.xml in your home directory\) and assign the value 'other' to property 'reason'\. You could do this with: \-\-detect\.maven\.build\.command='\-\-settings \\$\{HOME\}/maven\_dev\_settings\.xml \-\-define reason=other'

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Maven Executable
```
--detect.maven.path
```

The path to the Maven executable \(mvn or mvnw\)\.

If set, Detect will use the given Maven executable instead of searching for one\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Dependency Scope Included
```
--detect.maven.included.scopes
```

A comma separated list of Maven scopes\. Output will be limited to dependencies within these scopes \(overridden by exclude\)\.

If set, Detect will include only dependencies of the given Maven scope\. This property accepts filename globbing\-style wildcards\. This property accepts filename globbing\-style wildcards\. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details\.

|Details||
|---|---|
|Added|6\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Dependency Scope Excluded
```
--detect.maven.excluded.scopes
```

A comma separated list of Maven scopes\. Output will be limited to dependencies outside these scopes \(overrides include\)\.

If set, Detect will include only dependencies outside of the given Maven scope\. This property accepts filename globbing\-style wildcards\. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details\.

|Details||
|---|---|
|Added|6\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|Any|
|Strict|No|
|Example|``|


## Maven Modules Excluded (Advanced)
```
--detect.maven.excluded.modules
```

A comma\-separated list of Maven modules \(sub\-projects\) to exclude\.

As Detect parses the mvn dependency:tree output for dependencies, Detect will skip any Maven modules specified via this property\. This property accepts filename globbing\-style wildcards\. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Maven Modules Included (Advanced)
```
--detect.maven.included.modules
```

A comma\-separated list of Maven modules \(sub\-projects\) to include\.

As Detect parses the mvn dependency:tree output for dependencies, if this property is set, Detect will include only those Maven modules specified via this property that are not excluded\. Leaving this unset implies 'include all'\. Exclusion rules always win\. This property accepts filename globbing\-style wildcards\. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|Any|
|Strict|No|
|Example|``|



## Maven Include Plugins (Deprecated) 
```
--detect.maven.include.plugins=false
```

Whether or not detect will include the plugins section when parsing a pom\.xml in buildless legacy mode\. 



**DEPRECATED: This property is being removed\. The project inspector will be used to parse maven projects\. Please configure the project inspector to include modules\. It will be removed in 8\.0\.0.**

|Details||
|---|---|
|Added|5\.6\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Maven Buildless Legacy Mode (Deprecated) 
```
--detect.maven.buildless.legacy.mode=true
```

Legacy maven parsing supports plugins but the newer project inspector parser does not\. Setting to false enables the project inspector for maven\.



**DEPRECATED: This property is being removed\. The legacy maven buildless parser is being replaced by the project inspector\. It will be removed in 8\.0\.0.**

|Details||
|---|---|
|Added|7\.5\.0|
|Type|Boolean|
|Default Value|true|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

